*******
repytah
*******
``repytah`` is a Python package that builds aligned hierarchies, a representation for 
sequential data streams. 

Citing repytah
==============
Please cite ``repytah`` using the following:

C. Jia et al., repytah: A Python package that builds aligned hierarchies for sequential data streams. Python package version 0.1.0, 2023. [Online]. Available: [https://github.com/smith-tinkerlab/repytah](https://github.com/smith-tinkerlab/repytah).


.. toctree::
   :maxdepth: 1
   :caption: Getting Started
   
   about
   recommended_installation
   general_installation


.. toctree::
   :maxdepth: 1
   :caption: Modules

   utilities_import
   transform_import
   assemble_import
   search_import


.. toctree::
   :maxdepth: 1
   :caption: Implementation
   
   function_pipeline
   quick_start.ipynb
   example_vignette.ipynb


.. toctree::
   :maxdepth: 1
   :caption: References

   changelog
   genindex
